@@ -489,8 +489,7 @@ gl_nir_lower_blend_equation_advanced(nir_shader *sh, bool coherent)
    nir_function_impl *impl = nir_shader_get_entrypoint(sh);
 
    if (sh->info.fs.advanced_blend_modes == 0) {
-      nir_metadata_preserve(impl, nir_metadata_all);
-      return false;
+      return nir_no_progress(impl);
    }
 
    sh->info.fs.uses_sample_shading = true;
@@ -575,13 +574,13 @@ gl_nir_lower_blend_equation_advanced(nir_shader *sh, bool coherent)
       }
    }
 
-   nir_metadata_preserve(impl, nir_metadata_none);
+   nir_progress(true, impl, nir_metadata_none);
 
    /* Remove any dead writes before assigning location to __blend_fb_fetch
     * otherwise they will be unable to be removed.
     */
-   NIR_PASS_V(sh, nir_split_var_copies);
-   NIR_PASS_V(sh, nir_opt_dead_write_vars);
+   NIR_PASS(_, sh, nir_split_var_copies);
+   NIR_PASS(_, sh, nir_opt_dead_write_vars);
 
    nir_foreach_variable_with_modes(var, sh, nir_var_shader_out) {
       if (strcmp(var->name, "__blend_fb_fetch") == 0) {
